==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCInfo/nickName/index.js <==
import React from 'react'
import tost from "kara-module-tost"
import 'kara-module-tost/lib/index.css'
import css from '../index.scss'

export default class NickName extends React.Component{
  constructor(props)
  {
    super(props)
    this.state = {
      editName: false,
      changeNickName: '',
    }
    this.inputNickName = React.createRef()
  }

  editNickName = () => {
    this.setState({editName: !this.state.editName}, ()=>{this.inputNickName.current.focus()})
  }

  updateNickName = (e) => {
    const { httpAgent, nickName='', updateNickName, lang } = this.props
    const value = e.target.value
    if(value.trim() !== nickName){
      httpAgent.post('/sdm/authAccount.modify',{
        nickName: value
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') {
            updateNickName(value)
            tost({type:'success',msg:lang.updateSuccess,time:4})
          }
          else {
            tost({type:'error',msg:lang.updateError,time:4})
          }
        }
      )
    }
    this.setState({editName: false})
  }

  onChangeNickName = (e) => {
    const {lang} = this.props
    const value = e.target.value
    if(value.length > 30) {
      tost({type:'warn',msg:lang.noMore30})
    }
    const changeNickName = value.slice(0,30)
    this.setState({changeNickName})
  }

  render () {
    const {lang, nickName} = this.props
    const {changeNickName} = this.state
    return (<div className="clearfix">
      <span className='s-hint'>{lang.nickName}</span>
      <span className={this.state.editName ? css.hide : ''}>{nickName || lang.noNickName}</span>
      <span className={!this.state.editName ? css.hide : ''}>
              <input
                ref={this.inputNickName}
                className='s-b-primary'
                type='text'
                value={changeNickName}
                onBlur={this.updateNickName}
                onChange={this.onChangeNickName}
              />
            </span>
      <span className='s-primary' onClick={this.editNickName}><i className='kuc-iconfont kuc-edit'></i>&nbsp;&nbsp;{lang.edit}</span>
    </div>)
  }
}

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCInfo/nickName/index.js <==
import React from 'react'
import tost from "kara-module-tost"
import 'kara-module-tost/lib/index.css'
import css from '../index.scss'

export default class NickName extends React.Component{
  constructor(props)
  {
    super(props)
    this.state = {
      editName: false,
      changeNickName: '',
    }
    this.inputNickName = React.createRef()
  }

  editNickName = () => {
    this.setState({editName: !this.state.editName}, ()=>{this.inputNickName.current.focus()})
  }

  updateNickName = (e) => {
    const { httpAgent, nickName='', updateNickName, lang } = this.props
    const value = e.target.value
    if(value.trim() !== nickName){
      httpAgent.post('/sdm/authAccount.modify',{
        nickName: value
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') {
            updateNickName(value)
            tost({type:'success',msg:lang.updateSuccess,time:4})
          }
          else {
            tost({type:'error',msg:lang.updateError,time:4})
          }
        }
      )
    }
    this.setState({editName: false})
  }

  onChangeNickName = (e) => {
    const {lang} = this.props
    const value = e.target.value
    if(value.length > 30) {
      tost({type:'warn',msg:lang.noMore30})
    } else {
        this.setState({changeNickName : value})
    }
  }

  onKeyDownNickName = (e) => {
      if (e.keyCode === 13) {
          this.updateNickName(e)
      }
  }

  render () {
    const {lang, nickName} = this.props
    const {changeNickName} = this.state
    return (<div className="clearfix">
      <span className='s-hint'>{lang.nickName}</span>
      <span className={this.state.editName ? css.hide : ''}>{nickName || lang.noNickName}</span>
      <span className={!this.state.editName ? css.hide : ''}>
              <input
                ref={this.inputNickName}
                className='s-b-primary'
                type='text'
                value={changeNickName}
                onBlur={this.updateNickName}
                onChange={this.onChangeNickName}
                onKeyDown={this.onKeyDownNickName}
              />
            </span>
      <span className='s-primary' onClick={this.editNickName}><i className='kuc-iconfont kuc-edit'></i>&nbsp;&nbsp;{lang.edit}</span>
    </div>)
  }
}
